@@ -8,7 +8,9 @@ setMethod("plot", "dwi", function(x, y, ...) cat("No implementation for class dw
 
 ##############
 
-setMethod("plot", "dtiData", function(x, y,slice=1, gradient=NULL, view= "axial", show=TRUE, density=FALSE, xind=NULL, yind=NULL, zind=NULL, mar=c(3,3,3,.3), mgp=c(2,1,0), ...) {
+setMethod("plot", "dtiData", function(x, y,slice=1, gradient=NULL, view= "axial",
+                                      show=TRUE, density=FALSE, xind=NULL, yind=NULL,
+                                      zind=NULL, mar=par("mar"),mgp=par("mgp"), ...) {
   if(is.null(x@si)) cat("No dwi data yet")
   maxsi <- max(x@si)
   if(is.null(xind)) xind<-(1:x@ddim[1])
@@ -19,10 +21,10 @@ setMethod("plot", "dtiData", function(x, y,slice=1, gradient=NULL, view= "axial"
     warning("gradient number out of range, show s0 image")
     gradient <- x@s0ind[1]
   }
-  if(density) { 
+  if(density) {
     z <- density(x@si[xind,yind,zind,gradient])
     if(show) {
-      plot(z,main="Density of S0-values") 
+      plot(z,main="Density of S0-values")
       lines(c(x@level,x@level),c(0,max(z$y)),col=2)
     }
     return(invisible(z))
@@ -60,7 +62,10 @@ setMethod("plot", "dtiData", function(x, y,slice=1, gradient=NULL, view= "axial"
 
 ##############
 
-setMethod("plot", "dtiTensor", function(x, y, slice=1, view="axial", quant=0, minfa=NULL, contrast.enh=1,what="fa", qrange=c(.01,.99),xind=NULL,yind=NULL,zind=NULL, mar=c(2,2,2,.2),mgp=c(2,1,0),...) {
+setMethod("plot", "dtiTensor", function(x, y, slice=1, view="axial", quant=0, minfa=NULL,
+                                        contrast.enh=1,what="fa", qrange=c(.01,.99),
+                                        xind=NULL,yind=NULL,zind=NULL, mar=par("mar"),
+                                        mgp=par("mgp"),...) {
   if(is.null(x@D)) cat("No diffusion tensor yet")
   #adimpro <- require(adimpro)
   if(is.null(xind)) xind<-(1:x@ddim[1])
@@ -83,23 +88,21 @@ setMethod("plot", "dtiTensor", function(x, y, slice=1, view="axial", quant=0, mi
     n2 <- length(yind)
   }
   if(what=="GA"){
-    z <- .Fortran("dti2Dga",
+    z <- .Fortran(C_dti2dga,
                   as.double(D),
                   as.integer(n1*n2),
                   as.logical(mask),
                   fa=double(n1*n2),
                   md=double(n1*n2),
-                  andir=double(3*n1*n2),
-                  PACKAGE="dti")[c("fa","md","andir")]
+                  andir=double(3*n1*n2))[c("fa","md","andir")]
   } else {
-    z <- .Fortran("dti2Dfa",
+    z <- .Fortran(C_dti2dfa,
                   as.double(D),
                   as.integer(n1*n2),
                   as.logical(mask),
                   fa=double(n1*n2),
                   md=double(n1*n2),
-                  andir=double(3*n1*n2),
-                  PACKAGE="dti")[c("fa","md","andir")]
+                  andir=double(3*n1*n2))[c("fa","md","andir")]
   }
   oldpar <- par(mfrow=c(3,3),mar=mar,mgp=mgp,...)
   #  now draw information to graphical device
@@ -166,7 +169,9 @@ setMethod("plot", "dtiTensor", function(x, y, slice=1, view="axial", quant=0, mi
 
 ##############
 
-setMethod("plot", "dwiMixtensor", function(x, y, slice=1, view="axial", what="fa", minfa=NULL, identify=FALSE,  xind=NULL,yind=NULL,zind=NULL, mar=c(2,2,2,.2),mgp=c(2,1,0),...) {
+setMethod("plot", "dwiMixtensor", function(x, y, slice=1, view="axial", what="fa", minfa=NULL,
+                                           identify=FALSE,  xind=NULL,yind=NULL,zind=NULL,
+                                           mar=par("mar"),mgp=par("mgp"),...) {
   #adimpro <- require(adimpro)
   if(is.null(xind)) xind<-(1:x@ddim[1])
   if(is.null(yind)) yind<-(1:x@ddim[2])
@@ -182,33 +187,38 @@ setMethod("plot", "dwiMixtensor", function(x, y, slice=1, view="axial", what="fa
   stats <- extract(x,what)
   oldpar <- par(mfrow=c(1,length(what)),mar=mar,mgp=mgp,...)
   on.exit(par(oldpar))
+  if("w0" %in% what){
+    w0 <- drop(stats$w0)
+    show.image(img <- make.image(65535*w0))
+    title(paste("Isotropic compartment size"))
+  }
   if("fa" %in% what){
     fa <- drop(stats$fa)
     if(!is.null(minfa)) fa[fa<minfa] <- 0
     show.image(img <- make.image(65535*fa))
-    title(paste("Slice",slice,"FA"))
+    title(paste("effective FA"))
   }
   if("order" %in% what){
     order <- drop(stats$order)
     show.image(img <- make.image(65535*order/max(order)))
-    title(paste("Slice",slice,"Order of mixture (Maximum=",max(order),")"))
+    title(paste("Order of mixture (Maximum=",max(order),")"))
   }
   if("eorder" %in% what){
     eorder <- drop(stats$eorder)
     show.image(img <- make.image(65535*eorder/max(eorder)))
-    title(paste("Slice",slice,"Effective order of mixture (Maximum=",signif(max(eorder),2),")"))
+    title(paste("Eff. order of mixture (Maximum=",signif(max(eorder),2),")"))
   }
   if("ev" %in% what){
     ev <- drop(stats$ev[1,,,])
     show.image(img <- make.image(65535*ev/max(ev)))
-    title(paste("Slice",slice,"Maximal Eigenvalue (Maximum=",signif(max(ev),3),")"))
+    title(paste("Maximal Eigenvalue (Maximum=",signif(max(ev),3),")"))
   }
   if(identify){
     xind<-(1:x@ddim[1])
     yind<-(1:x@ddim[2])
     zind<-(1:x@ddim[3])
     img <- extract.image(img)
-    image(1:dim(img)[1],1:dim(img)[2],img,col=grey((0:255)/255))
+    image(1:dim(img)[1],1:dim(img)[2],img,col=grey((0:255)/255), asp=TRUE)
     identifyFA(view,slice,xind,yind,zind)
   } else {
     par(oldpar)
@@ -218,7 +228,10 @@ setMethod("plot", "dwiMixtensor", function(x, y, slice=1, view="axial", what="fa
 
 ##############
 
-setMethod("plot", "dtiIndices", function(x, y, slice=1, view= "axial", method=1, quant=0, minfa=NULL, show=TRUE, identify=FALSE, density=FALSE, contrast.enh=1,what="fa",xind=NULL,yind=NULL,zind=NULL, mar=c(3,3,3,.3),mgp=c(2,1,0), ...) {
+setMethod("plot", "dtiIndices", function(x, y, slice=1, view= "axial", method=1, quant=0, minfa=NULL,
+                                         show=TRUE, identify=FALSE, density=FALSE, contrast.enh=1,
+                                         what="fa", xind=NULL, yind=NULL, zind=NULL,
+                                         mar=par("mar"), mgp=par("mgp"), ...) {
   what <- tolower(what)
   if(is.null(x@fa)) cat("No anisotropy index yet")
   if(!(method %in% 1:6)) {
@@ -228,11 +241,11 @@ setMethod("plot", "dtiIndices", function(x, y, slice=1, view= "axial", method=1,
   if(is.null(xind)) xind<-(1:x@ddim[1])
   if(is.null(yind)) yind<-(1:x@ddim[2])
   if(is.null(zind)) zind<-(1:x@ddim[3])
-  if(density) { 
+  if(density) {
     x <- x[xind,yind,zind]
     z <- density(if(what=="fa") x@fa[x@fa>0] else x@ga[x@ga>0])
     if(show) {
-      plot(z,main=paste("Density of positive",what,"-values")) 
+      plot(z,main=paste("Density of positive",what,"-values"))
     }
     return(invisible(z))
   }
@@ -357,7 +370,7 @@ setMethod("plot", "dtiIndices", function(x, y, slice=1, view= "axial", method=1,
     img.data <- array(0, dim=c(dim(anindex), 3))
     for (i in 1:dim(anindex)[1]) { # i dont like for loops in R!
       for (j in 1:dim(anindex)[2]) {
-        img.data[i,j,] <- colqFA[, 255 * anindex[i, j] + 1] 
+        img.data[i,j,] <- colqFA[, 255 * anindex[i, j] + 1]
       }
     }
     img <- make.image(img.data, gammatype="ITU")
@@ -386,31 +399,32 @@ setMethod("plot", "dwiFiber", function(x, y, ...) {
   invisible(NULL)
 })
 
-setMethod("plot", "dkiIndices", function(x, 
-                                         y, 
-                                         slice = 1, 
-                                         #view = "axial", 
-                                         what = c("md", "fa", "mk", "mk2"),
-                                         #method = 1, 
-                                         #quant = 0, 
-                                         #minfa = NULL, 
-                                         #show = TRUE, 
-                                         #identify = FALSE, 
-                                         #density = FALSE, 
+setMethod("plot", "dkiIndices", function(x,
+                                         y,
+                                         slice = 1,
+                                         #view = "axial",
+                                         what = c("md", "fa", "mk", "mk2", "kaxial", "kradial", "fak"),
+                                         #method = 1,
+                                         #quant = 0,
+                                         #minfa = NULL,
+                                         #show = TRUE,
+                                         #identify = FALSE,
+                                         #density = FALSE,
                                          #contrast.enh = 1,
-                                         #xind = NULL,
-                                         #yind = NULL,
-                                         #zind = NULL, 
-                                         #mar = c(3, 3, 3, .3),
-                                         #mgp = c(2, 1, 0), 
+                                         xind = NULL,
+                                         yind = NULL,
+                                         #zind = NULL,
+                                         mar=par("mar"),
+                                         mgp=par("mgp"),
                                          ...) {
-  
+  if(is.null(xind)) xind <- 1:x@ddim[1]
+  if(is.null(yind)) yind <- 1:x@ddim[2]
   switch(what,
-         md = image(x@md[, , slice], col=grey(0:255/255), ...),
-         fa = image(x@fa[, , slice], col=grey(0:255/255), ...),
-         mk = image(x@mk[, , slice], col=grey(0:255/255), ...),
-         mk2 = image(x@mk2[, , slice], col=grey(0:255/255), ...))
-  
-  
-  
+         md = image(xind, yind, x@md[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...),
+         fa = image(xind, yind, x@fa[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...),
+         mk = image(xind, yind, x@mk[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...),
+         mk2 = image(xind, yind, x@mk2[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...),
+         kaxial = image(xind, yind, x@kaxial[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...),
+         kradial = image(xind, yind, x@kradial[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...),
+         fak = image(xind, yind, x@fak[xind, yind, slice], col=grey(0:255/255), asp=TRUE, ...))
 })
